<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [owl](#owl)
    -   [submitQuery](#submitquery)
    -   [getQueryResults](#getqueryresults)

## owl

An instance of the client.

**Parameters**

-   `opts` **[object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** Options to the constructor
    -   `opts.accessKeyId` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** AWS Access Key ID
    -   `opts.secretAccessKey` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** AWS corresponding AWS secret key
    -   `opts.region` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** AWS region (optional, default `us-east-1`)
    -   `opts.outputBucket` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** S3 location to store the results of queries (optional, default `s3://little-owl-athena-output`)

**Examples**

```javascript
const owl = require('little-owl')({
  accessKeyId: 'MY-AWS-ID',
  secretAccessKey: 'MY-AWS-SECRET'
})
```

### submitQuery

Submit a query and waits until it returns.

**Parameters**

-   `queryString` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** SQL statement
-   `callback` **submitQueryCallback** node callback (err, queryId)

**Examples**

```javascript
owl.submitQuery('SELECT * from owls', (err, queryId) => {
  if (!err) {
    console.log(queryId); // prints the query id
  }
});
```

### getQueryResults

Get results from a submitted query. The return object contains:
results: the results are an array of rows, each row an array of strings.
nextToken: if the number of results is larger than maxRows, use nextToken to return the next
set of values

**Parameters**

-   `queryId` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** Id of query
-   `opts` **[object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)?** Options
    -   `opts.maxRows` **[number](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number)** maximum number of rows returned (optional, default `1000`)
    -   `opts.nextToken` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)?** used for paginated results
-   `callback` **getQueryResultCallback** node callback (err, results)

**Examples**

```javascript
owl.getQueryResults('x2x4gas-12qwsd-a809', (err, data) => {
  if (!err) {
     console.log(data.results); // results is an array of rows
     console.log(data.nextToken); // data.nextToken is used for pagination
  }
});
```

```javascript
owl.getQueryResults('x2x4gas-12qwsd-a809', {nextToken: '91kaspejk13'}, (err, data) => {
  if (!err) {
     console.log(data.results); // results is an array of rows
  }
});
```
